---
sidebar_label: frequent_itemsets
title: data_structures.frequent_itemsets
---

## FrequentItemsets Objects

```python
class FrequentItemsets(DataStructure)
```

A datastructure to store Frequent Itemsets

